@@ -10,11 +10,11 @@ from . state import *
 
 __all__ = ('CommandLineClient', 'LoggingMixin', 'MqttClient',
     'Skill', 'SnipsClient', 'SnipsError', 'SnipsClarificationError',
-    'StateAwareMixin',
+    'StateAwareMixin', 'when',
     'debug_json', 'get_translations', 'topic', 'min_confidence', 'MultiRoomConfig',
     'on_intent', 'intent', 'PARDON', 'require_slot',
     'on_hotword_detected', 'on_start_session', 'on_session_started',
     'on_end_session', 'on_continue_session', 'on_session_ended', 'on_play_finished',
     'CONFIRMATIONS', 'ROOMS', 'room_with_article', 'room_with_preposition')
 
-__version__ = '0.1.10'
+__version__ = '0.1.11'
