@@ -1,7 +1,9 @@
+from functools import partial
+from . expr import Parser
 from . mqtt import topic
 
 
-__all__ = ('StateAwareMixin',)
+__all__ = ('StateAwareMixin', 'when')
 
 
 class StateAwareMixin:
@@ -14,6 +16,9 @@ class StateAwareMixin:
         e.g. `on_status_lamp_brightness(payload)`.
     '''
     
+    conditions = {}
+    parser = Parser()
+    
     def __init__(self):
         'Register topics and the state callcack.'
         
@@ -51,11 +56,27 @@ class StateAwareMixin:
     
     
     def invoke_handlers(self, topic, payload):
-        ''' Generic handler for status updates,
-            invokes topic specific handlers.
-        '''
-        method_name = 'on_%s' % topic.replace('/', '_')
-        if hasattr(self, method_name):
-            handler = getattr(self, method_name)
-            self.log.debug('Invoking: %s', method_name)
-            handler(payload)
+        'Run through conditions and invoke appropriate handlers'
+        for expr, action in self.conditions.items():
+            if topic not in expr.keys: continue
+            
+            id = action.func.__name__ if type(action) is partial else action.__name__
+            try:
+                if expr(self.current_state):
+                    self.log.info('Invoking: %s', id)
+                    action(self)
+                else:
+                    self.log.debug('Skipping: %s', id)
+            except KeyError as e:
+                self.log.warning('KeyError in %s: %s', id, e)
+
+
+def when(expression):
+    'Decorator for status handlers.'
+    
+    predicate = StateAwareMixin.parser.parse(expression)
+    
+    def wrapper(method):
+        StateAwareMixin.conditions[predicate] = method
+        return method
+    return wrapper
